@@ -1,7 +1,7 @@
 package Bencher::Scenario::LoggingModules::NullLogging;
 
 our $DATE = '2019-02-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -68,6 +68,16 @@ our $scenario = {
             name => 'Log::ger+LGP:OptAway-100k_log_trace',
             perl_cmdline_template => ['-MLog::ger::Plugin=OptAway', '-MLog::ger', '-e', 'for(1..100_000) { log_trace(q[]) }'],
         },
+        {
+            name => 'Log::ger-1mil_log_trace',
+            perl_cmdline_template => ['-MLog::ger', '-e', 'for(1..1_000_000) { log_trace(q[]) }'],
+            include_by_default => 0,
+        },
+        {
+            name => 'Log::ger+LGP:OptAway-1mil_log_trace',
+            perl_cmdline_template => ['-MLog::ger::Plugin=OptAway', '-MLog::ger', '-e', 'for(1..1_000_000) { log_trace(q[]) }'],
+            include_by_default => 0,
+        },
 
         {
             name => 'Log::Log4perl-easy-100k_trace' ,
@@ -106,7 +116,7 @@ Bencher::Scenario::LoggingModules::NullLogging - Benchmark logging statement tha
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::LoggingModules::NullLogging (from Perl distribution Bencher-Scenarios-LoggingModules), released on 2019-02-22.
+This document describes version 0.003 of Bencher::Scenario::LoggingModules::NullLogging (from Perl distribution Bencher-Scenarios-LoggingModules), released on 2019-02-22.
 
 =head1 SYNOPSIS
 
@@ -222,6 +232,22 @@ Command line:
 
 
 
+=item * Log::ger-1mil_log_trace (command) (not included by default)
+
+Command line:
+
+ #TEMPLATE: #perl -MLog::ger -e for(1..1_000_000) { log_trace(q[]) }
+
+
+
+=item * Log::ger+LGP:OptAway-1mil_log_trace (command) (not included by default)
+
+Command line:
+
+ #TEMPLATE: #perl -MLog::ger::Plugin=OptAway -MLog::ger -e for(1..1_000_000) { log_trace(q[]) }
+
+
+
 =item * Log::Log4perl-easy-100k_trace (command)
 
 Command line:
@@ -266,24 +292,35 @@ Benchmark with default options (C<< bencher -m LoggingModules::NullLogging >>):
  +-----------------------------------------+-----------+-------+------------+-----------+---------+
  | participant                             | rate (/s) |  time | vs_slowest |  errors   | samples |
  +-----------------------------------------+-----------+-------+------------+-----------+---------+
- | Log::Dispatch::Null-100k_debug          |       0.6 | 1.7   |        1   |   0.0018  |       6 |
- | Log::Contextual+Log4perl-100k_trace     |       1.5 | 0.66  |        2.5 |   0.004   |       7 |
- | Log::Contextual+SimpleLogger-100k_trace |       1.6 | 0.63  |        2.6 |   0.0012  |       6 |
- | Mojo::Log-100k_debug                    |       3   | 0.3   |        5   |   0.0068  |       7 |
- | Log::Dispatchouli-100k_debug            |       4.9 | 0.2   |        8.2 |   0.00047 |       7 |
- | Log::Log4perl::Tiny-100k_trace          |       7.5 | 0.13  |       13   |   0.00014 |       6 |
- | Log::Mini-100k_trace                    |      11   | 0.088 |       19   |   0.0002  |       6 |
- | Log::Any-null_adapter-100k_log_trace    |      13   | 0.078 |       22   |   0.00028 |       6 |
- | Log::Log4perl-easy-100k_trace           |      15   | 0.066 |       25   |   0.00027 |       7 |
- | Log::Fast-100k_DEBUG                    |      20   | 0.05  |       30   |   0.00092 |       7 |
- | Log::Any-no_adapter-100k_log_trace      |      35   | 0.029 |       58   |   4e-05   |       6 |
- | Log::ger+LGP:OptAway-100k_log_trace     |      40   | 0.02  |       70   |   0.00069 |       7 |
- | Log::ger-100k_log_trace                 |      51   | 0.019 |       86   | 9.9e-05   |       6 |
+ | Log::Dispatch::Null-100k_debug          |      0.59 | 1.7   |        1   |   0.013   |       7 |
+ | Log::Contextual+Log4perl-100k_trace     |      1.5  | 0.66  |        2.6 |   0.0031  |       7 |
+ | Log::Contextual+SimpleLogger-100k_trace |      1.6  | 0.64  |        2.6 |   0.0027  |       6 |
+ | Mojo::Log-100k_debug                    |      3.1  | 0.32  |        5.3 |   0.00088 |       6 |
+ | Log::Dispatchouli-100k_debug            |      4.7  | 0.21  |        7.9 |   0.00092 |       6 |
+ | Log::Log4perl::Tiny-100k_trace          |      7.4  | 0.14  |       12   |   0.00064 |       6 |
+ | Log::Mini-100k_trace                    |     11    | 0.088 |       19   |   0.00045 |       7 |
+ | Log::Any-null_adapter-100k_log_trace    |     13    | 0.078 |       22   |   0.00018 |       8 |
+ | Log::Log4perl-easy-100k_trace           |     15    | 0.067 |       25   |   0.00043 |       6 |
+ | Log::Fast-100k_DEBUG                    |     22    | 0.045 |       38   | 9.4e-05   |       8 |
+ | Log::Any-no_adapter-100k_log_trace      |     34    | 0.029 |       57   | 4.7e-05   |       6 |
+ | Log::ger+LGP:OptAway-100k_log_trace     |     40    | 0.02  |       70   |   0.00046 |       6 |
+ | Log::ger-100k_log_trace                 |     61    | 0.017 |      100   | 5.2e-05   |       6 |
  +-----------------------------------------+-----------+-------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
+=head1 BENCHMARK NOTES
+
+You might notice that L<Log::ger>+L<Log::ger::Plugin::OptAway> (LGP:OptAway) is
+slower than plain Log::ger at 100k trace. This is because the plugin loading and
+setup overhead eclipses the gain provided by the OptAway plugin. If you try the
+these not-included-by-default participants they will show the benefit of
+OptAway:
+
+ Log::ger-1mil_log_trace
+ Log::ger+LGP:OptAway-1mil_log_trace
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-LoggingModules>.
