@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LoggingModules::NullLogging;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -8,108 +8,108 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0018,
+        errors => 0.013,
         participant => "Log::Dispatch::Null-100k_debug",
-        rate => 0.6,
-        samples => 6,
+        rate => 0.59,
+        samples => 7,
         time => 1.7,
         vs_slowest => 1,
       },
       {
-        errors => 0.004,
+        errors => 0.0031,
         participant => "Log::Contextual+Log4perl-100k_trace",
         rate => 1.5,
         samples => 7,
         time => 0.66,
-        vs_slowest => 2.5,
-      },
-      {
-        errors => 0.0012,
-        participant => "Log::Contextual+SimpleLogger-100k_trace",
-        rate => 1.6,
-        samples => 6,
-        time => 0.63,
         vs_slowest => 2.6,
       },
       {
-        errors => 0.0068,
-        participant => "Mojo::Log-100k_debug",
-        rate => 3,
-        samples => 7,
-        time => 0.3,
-        vs_slowest => 5,
-      },
-      {
-        errors => 0.00047,
-        participant => "Log::Dispatchouli-100k_debug",
-        rate => 4.9,
-        samples => 7,
-        time => 0.2,
-        vs_slowest => 8.2,
-      },
-      {
-        errors => 0.00014,
-        participant => "Log::Log4perl::Tiny-100k_trace",
-        rate => 7.5,
+        errors => 0.0027,
+        participant => "Log::Contextual+SimpleLogger-100k_trace",
+        rate => 1.6,
         samples => 6,
-        time => 0.13,
-        vs_slowest => 13,
+        time => 0.64,
+        vs_slowest => 2.6,
       },
       {
-        errors => 0.0002,
+        errors => 0.00088,
+        participant => "Mojo::Log-100k_debug",
+        rate => 3.1,
+        samples => 6,
+        time => 0.32,
+        vs_slowest => 5.3,
+      },
+      {
+        errors => 0.00092,
+        participant => "Log::Dispatchouli-100k_debug",
+        rate => 4.7,
+        samples => 6,
+        time => 0.21,
+        vs_slowest => 7.9,
+      },
+      {
+        errors => 0.00064,
+        participant => "Log::Log4perl::Tiny-100k_trace",
+        rate => 7.4,
+        samples => 6,
+        time => 0.14,
+        vs_slowest => 12,
+      },
+      {
+        errors => 0.00045,
         participant => "Log::Mini-100k_trace",
         rate => 11,
-        samples => 6,
+        samples => 7,
         time => 0.088,
         vs_slowest => 19,
       },
       {
-        errors => 0.00028,
+        errors => 0.00018,
         participant => "Log::Any-null_adapter-100k_log_trace",
         rate => 13,
-        samples => 6,
+        samples => 8,
         time => 0.078,
         vs_slowest => 22,
       },
       {
-        errors => 0.00027,
+        errors => 0.00043,
         participant => "Log::Log4perl-easy-100k_trace",
         rate => 15,
-        samples => 7,
-        time => 0.066,
+        samples => 6,
+        time => 0.067,
         vs_slowest => 25,
       },
       {
-        errors => 0.00092,
+        errors => 9.4e-05,
         participant => "Log::Fast-100k_DEBUG",
-        rate => 20,
-        samples => 7,
-        time => 0.05,
-        vs_slowest => 30,
+        rate => 22,
+        samples => 8,
+        time => 0.045,
+        vs_slowest => 38,
       },
       {
-        errors => 4e-05,
+        errors => 4.7e-05,
         participant => "Log::Any-no_adapter-100k_log_trace",
-        rate => 35,
+        rate => 34,
         samples => 6,
         time => 0.029,
-        vs_slowest => 58,
+        vs_slowest => 57,
       },
       {
-        errors => 0.00069,
+        errors => 0.00046,
         participant => "Log::ger+LGP:OptAway-100k_log_trace",
         rate => 40,
-        samples => 7,
+        samples => 6,
         time => 0.02,
         vs_slowest => 70,
       },
       {
-        errors => 9.9e-05,
+        errors => 5.2e-05,
         participant => "Log::ger-100k_log_trace",
-        rate => 51,
+        rate => 61,
         samples => 6,
-        time => 0.019,
-        vs_slowest => 86,
+        time => 0.017,
+        vs_slowest => 100,
       },
     ],
     {
@@ -213,7 +213,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "2671.630",
+                                              speed                        => 3202.929,
                                               stepping                     => 7,
                                             },
                                             {
@@ -308,7 +308,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3143.896,
+                                              speed                        => 3274.639,
                                               stepping                     => 7,
                                             },
                                             {
@@ -403,7 +403,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2906.817,
+                                              speed                        => 3210.687,
                                               stepping                     => 7,
                                             },
                                             {
@@ -498,11 +498,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2820.538,
+                                              speed                        => 3254.772,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 33.2853660583496,
+      "func.elapsed_time"              => 31.50710105896,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                                    => 1.041,
@@ -524,7 +524,7 @@ our $results = [
                                             "Sys::Info"                                      => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 12]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 8, 11 .. 14]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "sonya",
@@ -550,13 +550,13 @@ our $results = [
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::LoggingModules::NullLogging",
-      "func.scenario_module_md5sum"    => "812970db708f76d7df268a0df49ad8f7",
-      "func.scenario_module_mtime"     => 1550803999,
-      "func.scenario_module_sha1sum"   => "f162e27da75bceaedd54a549ac92dc1c8eb2663f",
-      "func.scenario_module_sha256sum" => "924672f9025f17ddda92f616da4cd82a6e518f6788c616345f02571f3dbb3c2d",
-      "func.time_end"                  => 1550804550.87089,
+      "func.scenario_module_md5sum"    => "25ccf53b6a4781d81110d58fd741487c",
+      "func.scenario_module_mtime"     => 1550806694,
+      "func.scenario_module_sha1sum"   => "c358fce54e80259799aa557f737b9ac863635cf6",
+      "func.scenario_module_sha256sum" => "bfaf86a8aede40ae10ede1cc1ac898cf11f52a6776876422ea4882c9cb8562b5",
+      "func.time_end"                  => 1550806834.95489,
       "func.time_factor"               => 1,
-      "func.time_start"                => 1550804517.58553,
+      "func.time_start"                => 1550806803.44779,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s"],
       "table.fields"                   => [
